@@ -93,9 +93,7 @@ class EngagementRateFB:
                 df_fan_count["created_at"] = pd.to_datetime(
                     df_fan_count["created_at"]
                 ) - timedelta(hours=5)
-                df_fan_count["date"] = df_fan_count["created_at"].apply(
-                    lambda d: d.date
-                )
+                df_fan_count["date"] = df_fan_count["created_at"].dt.date
                 df_fan_count = df_fan_count.drop(columns=["created_at"])
 
                 df_posts_full = deepcopy(df_posts[POSTS_COLUMNS])
@@ -110,9 +108,7 @@ class EngagementRateFB:
                 df_posts_full["created_time"] = pd.to_datetime(
                     df_posts_full["created_time"]
                 ) - timedelta(hours=5)
-                df_posts_full["date"] = df_posts_full["created_time"].apply(
-                    lambda d: d.date
-                )
+                df_posts_full["date"] = df_posts_full["created_time"].dt.date
                 df_posts_full = pd.merge(
                     df_posts_full, df_fan_count, on=["page_id", "date"], how="left"
                 )
@@ -255,7 +251,7 @@ class EngagementRateIG:
                     df_fan_count["date"] = pd.to_datetime(
                         df_fan_count["date"]
                     ) - timedelta(hours=5)
-                    df_fan_count["date"] = df_fan_count["date"].apply(lambda d: d.date)
+                    df_fan_count["date"] = df_fan_count["date"].dt.date
                     df_fan_count = (
                         df_fan_count.groupby(["userid", "date"]).last().reset_index()
                     )
@@ -276,9 +272,7 @@ class EngagementRateIG:
                     df_posts_full["date"] = pd.to_datetime(
                         df_posts_full["date"]
                     ) - timedelta(hours=5)
-                    df_posts_full["date"] = df_posts_full["date"].apply(
-                        lambda d: d.date
-                    )
+                    df_posts_full["date"] = df_posts_full["date"].dt.date
                     df_posts_full = pd.merge(
                         df_posts_full, df_fan_count, on=["owner_id", "date"], how="left"
                     )
@@ -650,4 +644,4 @@ class EngagementRateTW:
             return pd.DataFrame(
                 columns=list(df_tweets_full.columns)
                         + ["engagement_rate_by_post", "boundary", "rel_engagement_rate_by_post"]
-            )
\ No newline at end of file
+            )
